@@ -172,7 +172,7 @@ def _gen(s: str):
     # Create context using seed content
     #
     context = {
-        'models': models,  # {name: {name, schema}}}
+        'models': models,  # {name: {names, schema}}}
         'layouts': [],  # [layout]
         'blueprints': [],  # [blueprint]
         'seeds': [],
@@ -202,6 +202,14 @@ def _gen(s: str):
                 # Remove dulplicated model at blueprint level
                 seed_model = seed['model']
                 models_by_name[seed_model['name']] = seed_model
+                # Add relation models
+                # TODO: Replace old __relations__, so that we do not need to check very detail schema here
+                for relation in seed_model['schema']['relations']:
+                    relation_schema = seed_model['schema']['properties'][relation]
+                    relation_model = relation_schema['items'] if relation_schema['type'] == 'array' else relation_schema
+                    #
+                    relation_model_name = relation_model['py_type']
+                    models_by_name[relation_model_name] = models[relation_model_name]
             #
             blueprint['views'].append(view)
             blueprint['models'] = models_by_name.values()
