@@ -20,7 +20,7 @@ import inflection
 from bson import ObjectId
 
 from .error import SchemaError, DataError, PathError
-from .utils import parse_layout
+from .utils import parse_layout, iterate_layout
 
 
 # ----------------------------------------------------------------------------------------------------------------------
@@ -433,7 +433,7 @@ class ModelMeta(ABCMeta):
         #
         for base in reversed(bases):
             if issubclass(base, BaseModel):  # True if base is BaseModel or its subclass
-                # BaseModel do not have __fields__ currently
+                # BaseModel do not have __fields__
                 if base is not BaseModel:
                     fields.update(deepcopy(base.__fields__))
                 # Id field's type should be defined in BaseModel/MongoModel, so we need to fetch them from bases
@@ -693,7 +693,22 @@ class BaseModel(metaclass=ModelMeta):
     # TODO: Validate all fields in layout are defined
     # Define fields can be show in query result table or card
     __columns__ = []
-    # Define layouts to render form or detail page
+    # Define field groups, which can be included by index in layouts
+    # e.g,
+    # __groups__ = [
+    #   '''
+    #   name, status
+    #   phone
+    #   ''',
+    #   '''
+    #   password
+    #   ''',
+    # ]
+    # __read__ = '''
+    #   $, (0, 1)
+    # '''
+    __groups__ = []
+    # Define layouts to render read or form page
     __layout__ = None
     __read__ = None
     __form__ = None
@@ -738,17 +753,26 @@ class BaseModel(metaclass=ModelMeta):
             #   Remember which users are removed and appended from team
             #   Add transaction support to update these users before updating team object
             #
-            if field_type.source_field_name is not None:
-                relation_value = data.get(field_type.source_field_name, Undefined)
+            if field_type.source_field_name is not None:  # e.g, team_id is created by team relation, so source field name of team_id is team
+                source_field = cls.__fields__[field_type.source_field_name]
+                relation_value = data.get(source_field.name, Undefined)  # get team value
                 # RelationField's value is lazy loaded, undefined means it is not load, so trust the value in current field
                 if relation_value is Undefined:
                     pass
                 # If it is not Undefined, means it is already loaded and may be updated programmtically, so overwrite current field
                 else:
                     if isinstance(relation_value, list):
-                        update_value = [getattr(v, cls.__id_name__) for v in relation_value]
+                        update_value = []
+                        for v in relation_value:
+                            if isinstance(v, dict):  # Value can be raw dict against related model
+                                update_value.append(v.get(cls.__id_name__))
+                            else:  # Value should be instance of relatited model
+                                update_value.append(getattr(v, cls.__id_name__))
                     else:
-                        update_value = getattr(relation_value, cls.__id_name__)
+                        if isinstance(relation_value, dict):
+                            update_value = relation_value.get(cls.__id_name__)
+                        else:
+                            update_value = getattr(relation_value, cls.__id_name__)
                     #
                     data[field_name] = update_value
             #
@@ -881,7 +905,7 @@ class BaseModel(metaclass=ModelMeta):
             if isinstance(field, RelationField):
                 # TODO: filter param is in mongodb's format, maybe more abstract approach is needed
                 if f_origin is None:
-                    # This is a back field created by relation field, means id is saved in the relation object
+                    # This is a back field created by relation field, means id is saved in one relation object
                     if field.is_back_field:
                         default = f_type.find_one({field.save_field_name: self.__dict__.get(f_type.__id_name__)})
                     else:
@@ -909,8 +933,11 @@ class BaseModel(metaclass=ModelMeta):
                         # Relation field is defined in Team using field name members, so the team ids store in a field name members_ids
                         #   members: List[User] -> User.find({_id: {$in: self.members_ids}})
                         ids = self.__dict__.get(field.save_field_name)
-                        default = list(l_type.find({l_type.__id_name__: {'$in': ids}}))
-                        default.sort(key=lambda i: ids.index(getattr(i, l_type.__id_name__)))
+                        if ids is None:
+                            default = []
+                        else:
+                            default = list(l_type.find({l_type.__id_name__: {'$in': ids}}))
+                            default.sort(key=lambda i: ids.index(getattr(i, l_type.__id_name__)))
                 elif f_origin is dict:
                     default = None
                 # If relation return None, we need to set the field to None
@@ -918,12 +945,11 @@ class BaseModel(metaclass=ModelMeta):
                 # This is a key step to implement the lazy loading for relation field
                 self.__setattr__(name, default)
             else:
+                default = None
                 if f_origin is None:
-                    default = None
                     if issubclass(f_type, BaseModel):
-                        # Do not create inner model automatically
-                        # defalut = type_()
-                        pass
+                        # Create inner model automatically
+                        default = f_type()
                 elif f_origin is list:
                     default = []
                 elif f_origin is dict:
@@ -1107,7 +1133,7 @@ class BaseModel(metaclass=ModelMeta):
                 check_parents = [type_.__name__] + parents
                 #
                 properties = {}
-                required, searchables, sortables = [], [], []
+                required, searchables, sortables, relations = [], [], [], []
                 for f_n, f_t in type_.__fields__.items():
                     field_schema = {}
                     origin = get_origin(f_t.type)
@@ -1184,6 +1210,10 @@ class BaseModel(metaclass=ModelMeta):
                     # sortable
                     if f_t.sortable is True:
                         sortables.append(f_n)
+                    # relation
+                    if isinstance(f_t, RelationField):
+                        field_schema.update({'is_relation': True})
+                        relations.append(f_n)
                     #
                     properties[f_n] = field_schema
                 #
@@ -1202,10 +1232,17 @@ class BaseModel(metaclass=ModelMeta):
                 obj['layout'] = layout
                 obj['read'] = parse_layout(type_.__read__)[0] if type_.__read__ else layout
                 obj['form'] = parse_layout(type_.__form__)[0] if type_.__form__ else layout
+                obj['groups'] = [parse_layout(g)[0] for g in type_.__groups__]
+                # each column in layout can be blank('')/summary($)/hyphen(-)/group(number)/field(string) suffixed with query and span string
+                # read_fields/form_fields just return field names
+                obj['read_fields'] = list(iterate_layout(obj['read'], obj['groups']))
+                obj['form_fields'] = list(iterate_layout(obj['form'], obj['groups']))
                 # searchables
                 obj['searchables'] = [('{}__{}'.format(*s) if s[1] != Comparator.EQ else s[0]) for s in searchables]
                 # sortables
                 obj['sortables'] = sortables
+                # relations
+                obj['relations'] = relations
                 #
                 return obj
             elif type_ is str:
@@ -1223,5 +1260,5 @@ class BaseModel(metaclass=ModelMeta):
 
         #
         ret = _gen_schema(cls)
-        #print(json.dumps(ret))
+        # print(json.dumps(ret))
         return ret
