@@ -54,7 +54,11 @@ def work_in(dirname=None):
 
 def generate_names(name):
     """ Generate names, which can be used directly in code generation. """
-    if name:
+    if name in ('', '-', '$') or re.match(r'[\d+]+', name):
+        return {
+            'name': name,
+        }
+    else:
         name_hyphen = re.sub(r'[.,?=#+]', '-', ''.join(name.split()))  # e.g, plan.members-form -> plan-members-form
         return {
             'name': name,  # => SampleModel
@@ -64,10 +68,7 @@ def generate_names(name):
             'name_snake': inflection.underscore(name_hyphen),  # => sample_model
             'name_snake_plural': inflection.tableize(name_hyphen),  # => sample_models
             'name_title': inflection.titleize(name_hyphen),  # => Sample Model
-        }
-    else:
-        return {
-            'name': '',
+            'name_title_lower': inflection.titleize(name_hyphen).lower(),  # => sample model
         }
 
 
@@ -97,7 +98,16 @@ def parse_layout(body, models={}):
     comma_regex = re.compile(r',\s*(?![^()]*\))')
 
     def _parse_column(column_str):
-        """ Parse column string. """
+        """ Parse column string.
+
+        Column string possible values:
+        1) blank column prints only a placeholder
+        2) row only contains one hyphen(-) prints <hr>
+        3) summary column($) prints model's summary
+        4) number column prints a group of fields, e.g, __groups__=['', ''], using 0 as column name should print groups[0]
+        5) single column with param and span, e.g, column?is_param=true#6
+        6) contains inner columns, e,g, (column?is_param=true, column)?is_param=true#6
+        """
         column_str = column_str.strip()
         ret = {}
         # Parse span at the end, i.e, a#4,(b,c)#8
@@ -107,7 +117,8 @@ def parse_layout(body, models={}):
             ret.update({'span': int(span_match.group(2))})
         # Check bracket
         bracket_match = bracke_regex.match(column_str)
-        if bracket_match:  # Inner column, e.g, a,(b,c)
+        # Inner column, e.g, a,(b,c)
+        if bracket_match:
             column_str = bracket_match.group(1)
             query_str = bracket_match.group(2)
             children = [_parse_column(cs) for cs in comma_regex.split(column_str)]
@@ -115,7 +126,8 @@ def parse_layout(body, models={}):
             # Join children's name
             # e.g, a,(b?p=1,c#6) -> b+c
             column_str = '+'.join(map(lambda x: x['name'], children))
-        else:  # Single level column, e.g, a,b,c
+        # Single level column, e.g, a,b,c
+        else:
             if '?' in column_str:
                 column_str, query_str = column_str.split('?')
             else:
@@ -141,9 +153,9 @@ def parse_layout(body, models={}):
                     ret.update({'model': found, 'sub': sub, 'action': action})
                     # Append to return seeds
                     seeds.append(ret)
-        #
+        # Names
         ret.update(generate_names(column_str))
-        #
+        # Params
         params = {}
         if query_str:
             # Parse params, i.e, a?is_card=true,(b,c)?is_tab=true
@@ -183,3 +195,23 @@ def parse_layout(body, models={}):
         rows.append(row)
     #
     return rows, seeds
+
+
+def iterate_layout(layout, groups=[]):
+    """ Each column in layout can be blank('')/hyphen(-)/summary($)/group(number)/field(string)/inner fields(has children), iterate the whole layout and return field names only.
+
+    :param layout: Parsed layout
+    :param groups: Group index in layout need to refer to this list
+    :return:
+    """
+    for row in layout:
+        for col in row:
+            col_name = col['name']
+            if col.get('children'):
+                yield from iterate_layout([col['children']], groups)
+            elif col_name.isdigit():
+                yield from iterate_layout(groups[int(col_name)], groups)
+            elif col_name in ('', '-', '$'):
+                pass
+            else:
+                yield col_name
